import type { OpenId4VcSiopCreateAuthorizationRequestOptions, OpenId4VcSiopCreateAuthorizationRequestReturn, OpenId4VcSiopCreateVerifierOptions, OpenId4VcSiopVerifiedAuthorizationResponse, OpenId4VcSiopVerifyAuthorizationResponseOptions } from './OpenId4VcSiopVerifierServiceOptions';
import type { AgentContext } from '@credo-ts/core';
import { Logger, W3cCredentialService } from '@credo-ts/core';
import { OpenId4VcVerifierModuleConfig } from './OpenId4VcVerifierModuleConfig';
import { OpenId4VcVerifierRecord, OpenId4VcVerifierRepository } from './repository';
/**
 * @internal
 */
export declare class OpenId4VcSiopVerifierService {
    private logger;
    private w3cCredentialService;
    private openId4VcVerifierRepository;
    private config;
    constructor(logger: Logger, w3cCredentialService: W3cCredentialService, openId4VcVerifierRepository: OpenId4VcVerifierRepository, config: OpenId4VcVerifierModuleConfig);
    createAuthorizationRequest(agentContext: AgentContext, options: OpenId4VcSiopCreateAuthorizationRequestOptions & {
        verifier: OpenId4VcVerifierRecord;
    }): Promise<OpenId4VcSiopCreateAuthorizationRequestReturn>;
    verifyAuthorizationResponse(agentContext: AgentContext, options: OpenId4VcSiopVerifyAuthorizationResponseOptions & {
        verifier: OpenId4VcVerifierRecord;
    }): Promise<OpenId4VcSiopVerifiedAuthorizationResponse>;
    getAllVerifiers(agentContext: AgentContext): Promise<OpenId4VcVerifierRecord[]>;
    getByVerifierId(agentContext: AgentContext, verifierId: string): Promise<OpenId4VcVerifierRecord>;
    updateVerifier(agentContext: AgentContext, verifier: OpenId4VcVerifierRecord): Promise<void>;
    createVerifier(agentContext: AgentContext, options?: OpenId4VcSiopCreateVerifierOptions): Promise<OpenId4VcVerifierRecord>;
    private getRelyingParty;
    private getPresentationVerificationCallback;
}
